using Domain.Entities;

namespace phronCare.UIBlazor.Services.Lookups
{
    public interface ISalesLookupService
    {
        Task<IEnumerable<ELookUpItem>> SearchCustomersAsync(string filtro);
        Task<IEnumerable<ELookUpItem>> SearchInstitutionsAsync(string filtro);
        Task<IEnumerable<ELookUpItem>> SearchPatientsAsync(string filtro);
        Task<IEnumerable<ELookUpItem>> SearchPeopleAsync(string filtro);
        Task<IEnumerable<ELookUpItem>> SearchProfessionalsAsync(string filtro);
        Task<IEnumerable<ELookUpItem>> SearchBussinessUnitsAsync(string filtro);
        Task<IEnumerable<EProductLookupItem>> SearchProductsAsync(string filtro);
        Task<IEnumerable<EAdjustmentReason>> GetAdjustmentReasonsAsync();
        Task<IEnumerable<ETaxType>> GetTaxTypesAsync();
        Task<IEnumerable<ELookUpItem>> GetPaymentTermsAsync();
        Task<IEnumerable<ELookUpItem>> SearchApprovedQuotesAsync(string filtro);
    }
}
